@@ -1,23 +1,51 @@
 package Mojolicious::Plugin::AdvancedMod;
-use Mojo::Base 'Mojolicious::Plugin';
 
-use Mojolicious::Plugin::AdvancedMod::ActionFilter;
-use Mojolicious::Plugin::AdvancedMod::HashedParams;
-use Mojolicious::Plugin::AdvancedMod::Configurator;
-use Mojolicious::Plugin::AdvancedMod::TagHelpers;
+our $VERSION = '0.38';
 
 use DBI;
-
-our $VERSION = '0.37';
+use List::Util 'any';
+use Mojo::Base 'Mojolicious::Plugin';
+use Data::Dumper;
+our $AVAILABLE_MODS = {
+  ActionFilter => 1,
+  Configurator => 1,
+  HashedParams => 1,
+  TagHelpers   => 1,
+  Authoriz     => 0,
+  Fake         => 1
+};
 
 sub register {
   my ( $plugin, $app, $conf ) = @_;
   my ( $helpers, %only ) = {};
 
-  Mojolicious::Plugin::AdvancedMod::ActionFilter::init( $app, $helpers );
-  Mojolicious::Plugin::AdvancedMod::Configurator::init( $app, $helpers );
-  Mojolicious::Plugin::AdvancedMod::HashedParams::init( $app, $helpers );
-  Mojolicious::Plugin::AdvancedMod::TagHelpers::multi_init( $app, $helpers );
+  foreach my $mod ( keys %$AVAILABLE_MODS ) {
+    unless( $AVAILABLE_MODS->{$mod} ) {
+      $app->log->debug( "** AdvancedMod $mod disable" );
+      next;
+    }
+
+    if ( $conf->{only_mods} ) {
+      unless ( any { lc( $_ ) eq lc( $mod ) } @{ $conf->{only_mods} } ) {
+        $app->log->debug( "** AdvancedMod skipped $mod" );
+        next;
+      }
+    }
+    elsif ( $conf->{skip_mods} ) {
+      if ( any { lc( $mod ) eq lc( $_ ) } @{ $conf->{skip_mods} } ) {
+        $app->log->debug( "** AdvancedMod skipped $mod" );
+        next;
+      }
+    }
+
+    eval "use Mojolicious::Plugin::AdvancedMod::$mod;";
+
+    # $app->defaults( { am_config => { errors => $@ } } ) if $@;
+
+    unless ( $@ ) {
+      eval 'Mojolicious::Plugin::AdvancedMod::' . $mod . '::init( $app, $helpers );';
+    }
+  }
 
   # add helper's
   if ( $conf->{only} ) {
@@ -63,12 +91,30 @@ Mojolicious::Plugin::AdvancedMod - More buns for Mojolicious
 
 =head1 VERSION
 
-This documentation covers version 0.37 of Mojolicious::Plugin::AdvancedMod* released Jan, 2014
+This documentation covers version 0.38 of Mojolicious::Plugin::AdvancedMod* released Jan, 2014
 
 =head1 SYNOPSIS
 
 $self->plugin('AdvancedMod');
 
+=head1 ARGS
+
+=head2 skip_mods
+
+  Skip selected modules
+
+=head2 skip_helpers
+
+  Skip selected helpers
+
+=head2 only_mods (dev)
+
+  Load selected modules, other skipped
+
+=head2 only_helpers (dev)
+
+  Load selected helpers, other skipped
+
 =head1 SEE ALSO
 
 =head2 L<Mojolicious::Plugin::AdvancedMod>
